@@ -5,7 +5,7 @@ use warnings;
 use Config;
 use Hash::Util qw(lock_hash);
 
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 =pod
 
@@ -74,8 +74,7 @@ sub dump {
         $attribs{$attrib_name} = 'define';
     }
     else {
-        delete( $attribs{$attrib_name} );
-        $attribs{"no_$attrib_name"} = 'define';
+        $attribs{$attrib_name} = '^$';
     }
 
     return \%attribs;
